# Changelog

## [0.0.12](https://github.com/nicscda/alpha-framework/compare/v0.0.11...v0.0.12) (2025-10-13)


### Bug Fixes

* :bug: update for correct path handling ([6f5dab8](https://github.com/nicscda/alpha-framework/commit/6f5dab87d83a21ccc80652a279fdb3d92da14a11))

## [0.0.11](https://github.com/nicscda/alpha-framework/compare/v0.0.10...v0.0.11) (2025-10-03)


### Bug Fixes

* :bug: package structure conflict ([#76](https://github.com/nicscda/alpha-framework/issues/76)) ([a785a4a](https://github.com/nicscda/alpha-framework/commit/a785a4adeee9148dab829f1af799882ea7862310))

## [0.0.10](https://github.com/nicscda/alpha-framework/compare/v0.0.9...v0.0.10) (2025-09-16)


### Bug Fixes

* :bug: missing manifest ([#74](https://github.com/nicscda/alpha-framework/issues/74)) ([6688a4b](https://github.com/nicscda/alpha-framework/commit/6688a4b15eb74762ba5a5de4ee12d0183bb6b7ab))

## [0.0.9](https://github.com/nicscda/alpha-framework/compare/v0.0.8...v0.0.9) (2025-09-16)


### Bug Fixes

* :bug: sync crash ([#72](https://github.com/nicscda/alpha-framework/issues/72)) ([3734489](https://github.com/nicscda/alpha-framework/commit/373448918df2f0d0be3814ea794984ee20378b16))

## [0.0.8](https://github.com/nicscda/alpha-framework/compare/v0.0.7...v0.0.8) (2025-09-16)


### Bug Fixes

* :pencil2: rename templates ([#70](https://github.com/nicscda/alpha-framework/issues/70)) ([9b9e5bb](https://github.com/nicscda/alpha-framework/commit/9b9e5bb1a4cbf2e761af6534dc817f366a74b364))

## [0.0.7](https://github.com/nicscda/alpha-framework/compare/v0.0.6...v0.0.7) (2025-09-15)


### Styles

* :lipstick: solve to connect CSS and webmanifest ([#68](https://github.com/nicscda/alpha-framework/issues/68)) ([cd47c9b](https://github.com/nicscda/alpha-framework/commit/cd47c9b12eff4c4877318f5f1aa13682518b44fe))

## [0.0.6](https://github.com/nicscda/alpha-framework/compare/v0.0.5...v0.0.6) (2025-09-15)


### Miscellaneous Chores

* :twisted_rightwards_arrows: update requirements ([#64](https://github.com/nicscda/alpha-framework/issues/64)) ([33bc031](https://github.com/nicscda/alpha-framework/commit/33bc031eee23a713fefb116d7d3a7e1c22bd7ecd))

## [0.0.5](https://github.com/nicscda/alpha-framework/compare/v0.0.4...v0.0.5) (2025-07-08)


### Continuous Integration

* :construction_worker: add sync-repo, improve CI/CD ([#53](https://github.com/nicscda/alpha-framework/issues/53)) ([7dea3a9](https://github.com/nicscda/alpha-framework/commit/7dea3a915524385516b3c43ff066861b9d4d5083))

## [0.0.4](https://github.com/nicscda/alpha-framework/compare/v0.0.3...v0.0.4) (2025-05-27)


### Bug Fixes

* :ambulance: missing package version ([3c06f76](https://github.com/nicscda/alpha-framework/commit/3c06f765d072624e685a81959d22789f2ae162da))

## [0.0.3](https://github.com/nicscda/alpha-framework/compare/v0.0.2...v0.0.3) (2025-05-27)


### Features

* :sparkles: add description and sub-items for T0061 ([23ab326](https://github.com/nicscda/alpha-framework/commit/23ab32636c1182519179787c0690086f9959c99f))
* :sparkles: add detection data files ([#33](https://github.com/nicscda/alpha-framework/issues/33)) ([ef01b93](https://github.com/nicscda/alpha-framework/commit/ef01b938c4db27213ec2f536eb0d167339759b13))
* :sparkles: add external_references ([fe8cc74](https://github.com/nicscda/alpha-framework/commit/fe8cc74be41d643416fb487ade30566dbfd3e724))
* :sparkles: add twelve mitigations ([f9bbd3d](https://github.com/nicscda/alpha-framework/commit/f9bbd3d64cfc4247fce1ea663d83a61ca342b75c))
* ✨ add twelve mitigations and three techniques ([#31](https://github.com/nicscda/alpha-framework/issues/31)) ([8e49bf9](https://github.com/nicscda/alpha-framework/commit/8e49bf9b816bd40ee754ab769efa2aa0b2b81b20))


### Bug Fixes

* :bug: adjust regex so URLs with numbers are valid ([bc1ec3b](https://github.com/nicscda/alpha-framework/commit/bc1ec3b7c16466514d7da8adbb53e6257f3a11a6))
* :bug: change some descriptions' symbols from &gt; to | ([fb8281b](https://github.com/nicscda/alpha-framework/commit/fb8281b2fed1420c1e51a99f377944c73a284ea5))
* :bug: find more general articles ([822ad86](https://github.com/nicscda/alpha-framework/commit/822ad8622120facebecfa1578801098693a1ed13))
* :bug: fix external_reference url's pattern ([a0bf385](https://github.com/nicscda/alpha-framework/commit/a0bf385b8406be47aa8e62731799da8f39dc2cf3))
* :bug: fix external_references writing style ([f29acfe](https://github.com/nicscda/alpha-framework/commit/f29acfe8671c8002992e269b2e0a59e75d313724))
* :bug: modify some description ([94261a8](https://github.com/nicscda/alpha-framework/commit/94261a864b3614e837fb39abf44c9ebd8b89de92))
* :bug: modify the description of certain terms ([e6b1997](https://github.com/nicscda/alpha-framework/commit/e6b19971b09bf45d5da59103915faf895bf2be77))
* :bug: provide more description ([a998b3d](https://github.com/nicscda/alpha-framework/commit/a998b3d9446acb9cbdd13c85b59e267f1dc98022))
* :bug: remove external_id ([89b13a2](https://github.com/nicscda/alpha-framework/commit/89b13a237351fcd90a21a7ce35a8e0ccf7dae881))


### Miscellaneous Chores

* :recycle: formatting, docs, LICENSE, infra, refactor ([#35](https://github.com/nicscda/alpha-framework/issues/35))([15831df](https://github.com/nicscda/alpha-framework/commit/15831df98126c6d8f860e77dc5f007b4d5d3d3fe))

## [0.0.2](https://github.com/nicscda/alpha-framework/compare/v0.0.1...v0.0.2) (2025-01-16)


### Features

* :lipstick: add favicon ([#28](https://github.com/nicscda/alpha-framework/issues/28)) ([62d8da4](https://github.com/nicscda/alpha-framework/commit/62d8da41b5b019a9a71588238ec186fa337313b7))


### Styles

* :lipstick: optimize typography ([03aeda0](https://github.com/nicscda/alpha-framework/commit/03aeda0995e92bf965e40be7186e4348497b634b))

## 0.0.1 (2025-01-15)


### ⚠ BREAKING CHANGES

* Improve the data modification experience.
* Switch to workflow-based control for GitHub Pages instead of branch-based deployment.

### Features

* :sparkles: add bundle file generator ([2543589](https://github.com/nicscda/alpha-framework/commit/25435898f8d5e1ff57215cae004a19b98a9ad6b1))
* :sparkles: add file to prepare for coding generator ([1f8efb3](https://github.com/nicscda/alpha-framework/commit/1f8efb39ceb0ad8fa6b29601aec845cf5fd469b4))
* :sparkles: add templates and markdown generator ([43332d7](https://github.com/nicscda/alpha-framework/commit/43332d7b62555971adb74ac575884d3b7c875be4))
* :sparkles: add workflow for preview testing ([e3ffe3f](https://github.com/nicscda/alpha-framework/commit/e3ffe3fe8c057a20518b446e535948d2a0682944))
* :tada: initial project ([d259a90](https://github.com/nicscda/alpha-framework/commit/d259a90fef9e3af474de543c7ba9e5f7e47b99b8))


### Bug Fixes

* :bug: adjust and optimize business logic ([6c89f32](https://github.com/nicscda/alpha-framework/commit/6c89f325c92248106c15db6dde207d410ec0c95e))


### Miscellaneous Chores

* :bento: update data framework ([c635eed](https://github.com/nicscda/alpha-framework/commit/c635eed83331ed38cf9abf4f7ead7bcb8067a93f))


### Build System

* :boom: merge gh-page and update workflow ([8af1fd1](https://github.com/nicscda/alpha-framework/commit/8af1fd1ebbd50118dcf5d93083b909f05ec1abce))
